@@ -8,12 +8,12 @@ import torch_model_loader
 from mobile_block import MobileBlock
 
 from .configs import MobileNetV2Config
-from .layers import GlobalPooling, InplaceReLU6
+from .layers import Flatten, GlobalPooling, InplaceReLU6
 
 
 @torch_model_loader.register
 class MobileNetV2(nn.Module):
-    with open(str(Path(__file__).parent / 'schema' / 'mobilenet_v2_config.yaml')) as f:
+    with open(str(Path(__file__).parent / 'schema' / 'mobilenet_v2_config.json')) as f:
         schema = json.load(f)
 
     def __init__(self, config: MobileNetV2Config, batch_norm_2d: Type[nn.BatchNorm2d]):
@@ -64,6 +64,7 @@ class MobileNetV2(nn.Module):
         last_channels = int(1280 * max(width_multiple, 1.0))
         blocks.append(self.conv_bn_relu(in_channels, last_channels, kernel=1, stride=1, batch_norm_2d=batch_norm_2d))
         blocks.append(GlobalPooling())
+        blocks.append(Flatten())
         blocks.append(nn.Linear(last_channels, config.feature_dim))
 
         self.blocks = nn.Sequential(*blocks)
